package com.gic.haoban.manage.service.service.role;

import com.gic.haoban.manage.service.entity.role.TabHaobanRoleMenu;

import java.util.List;

/**
 * 好办小程序权限菜单(TabHaobanRoleMenu)表服务接口
 *
 * @author mozhu
 * @since 2022-09-09 11:36:06
 */
public interface HaobanRoleMenuService {

    /**
     * 通过ID查询单条数据
     *
     * @param roleMenuId 主键
     * @return 实例对象
     */
    TabHaobanRoleMenu queryById(Long roleMenuId);

    /**
     * 新增数据
     *
     * @param tabHaobanRoleMenu 实例对象
     * @return 实例对象
     */
    int insert(TabHaobanRoleMenu tabHaobanRoleMenu);


    /**
     * 批量新增数据
     *
     * @param roleMenuList 角色菜单列表
     * @return int
     * @author mozhu
     * @date 2022-09-09 16:32:24
     */
    int insertBatch(List<TabHaobanRoleMenu> roleMenuList);

    /**
     * 修改数据
     *
     * @param tabHaobanRoleMenu 实例对象
     * @return 实例对象
     */
    int update(TabHaobanRoleMenu tabHaobanRoleMenu);

    /**
     * 通过主键删除数据
     *
     * @param roleMenuId 主键
     * @return 是否成功
     */
    boolean deleteById(Long roleMenuId);

    /**
     * 按角色删除id
     *
     * @param roleId 角色id
     * @return boolean
     * @author mozhu
     * @date 2022-09-09 17:18:19
     */
    boolean deleteByRoleId(Long roleId);

    /**
     * 通过wx企业id和角色id 查询菜单
     *
     * @param wxEnterpriseId wx企业标识
     * @param roleId         角色id
     * @return {@link List }<{@link String }>
     * @author mozhu
     * @date 2022-09-13 14:57:34
     */
    List<String> getByWxEnterpriseIdAndRoleId(String wxEnterpriseId, Long roleId);

    /**
     * 根据企业id删除权限
     *
     * @param wxEnterpriseId wx企业标识
     * @return boolean
     * @author mozhu
     * @date 2022-09-14 10:39:43
     */
    boolean deleteByWxEnterpriseId(String wxEnterpriseId);


    /**
     * 菜单没有菜单代码
     *
     * @param wxEnterpriseId wx企业标识
     * @param roleId         角色id
     * @param menuCodes      菜单代码
     * @return {@link List }<{@link String }>
     * @author mozhu
     * @date 2022-10-09 14:20:25
     */
    List<String> getMenuInMenuCodes(String wxEnterpriseId, Long roleId, List<String> menuCodes);


    /**
     * 根据code删除
     *
     * @param menuCode       菜单代码
     * @param wxEnterpriseId wx企业标识
     * @return boolean
     * @author mozhu
     * @date 2022-10-10 10:44:23
     */
    boolean deleteByMenuCode(String menuCode,String wxEnterpriseId);

}
